@@ -4,16 +4,11 @@
 import re
 import time
 import platform
+from collections import OrderedDict
 
 # 3rd party
 import six
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    # python 2.6 requires 3rd party library (backport)
-    from ordereddict import OrderedDict  # pylint: disable=import-error
-
 # curses
 if platform.system() == 'Windows':
     # pylint: disable=import-error
@@ -374,6 +369,10 @@ DEFAULT_SEQUENCE_MIXIN = (
     (u"\x1b[B", curses.KEY_DOWN),
     (u"\x1b[C", curses.KEY_RIGHT),
     (u"\x1b[D", curses.KEY_LEFT),
+    (u"\x1b[1;2A", curses.KEY_SR),
+    (u"\x1b[1;2B", curses.KEY_SF),
+    (u"\x1b[1;2C", curses.KEY_SRIGHT),
+    (u"\x1b[1;2D", curses.KEY_SLEFT),
     (u"\x1b[F", curses.KEY_END),
     (u"\x1b[H", curses.KEY_HOME),
     # not sure where these are from .. please report
