@@ -44,17 +44,14 @@ except NameError:
     # pylint: disable=redefined-builtin
     InterruptedError = select.error
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    # python 2.6 requires 3rd party library (backport)
-    from ordereddict import OrderedDict  # pylint: disable=import-error
-
 
 HAS_TTY = True
 if platform.system() == 'Windows':
+    IS_WINDOWS = True
     import jinxed as curses  # pylint: disable=import-error
+    from jinxed.win32 import get_console_input_encoding  # pylint: disable=import-error
 else:
+    IS_WINDOWS = False
     import curses
 
     try:
@@ -167,7 +164,7 @@ class Terminal(object):
         self._is_a_tty = False
         self.__init__streams()
 
-        if platform.system() == 'Windows' and self._init_descriptor is not None:
+        if IS_WINDOWS and self._init_descriptor is not None:
             self._kind = kind or curses.get_term(self._init_descriptor)
         else:
             self._kind = kind or os.environ.get('TERM', 'dumb') or 'dumb'
@@ -240,7 +237,7 @@ class Terminal(object):
         if self._stream in (sys.__stdout__, sys.__stderr__):
             try:
                 self._keyboard_fd = sys.__stdin__.fileno()
-            except ValueError as err:
+            except (AttributeError, ValueError) as err:
                 self.errors.append('Unable to determine input stream file descriptor: %s' % err)
             else:
                 # _keyboard_fd only non-None if both stdin and stdout is a tty.
@@ -278,7 +275,7 @@ class Terminal(object):
     def __init__capabilities(self):
         # important that we lay these in their ordered direction, so that our
         # preferred, 'color' over 'set_a_attributes1', for example.
-        self.caps = OrderedDict()
+        self.caps = collections.OrderedDict()
 
         # some static injected patterns, esp. without named attribute access.
         for name, (attribute, pattern) in CAPABILITIES_ADDITIVES.items():
@@ -331,7 +328,13 @@ class Terminal(object):
 
         if self._keyboard_fd is not None:
             # set input encoding and initialize incremental decoder
-            self._encoding = locale.getpreferredencoding() or 'UTF-8'
+
+            if IS_WINDOWS:
+                self._encoding = get_console_input_encoding() \
+                    or locale.getpreferredencoding() or 'UTF-8'
+            else:
+                self._encoding = locale.getpreferredencoding() or 'UTF-8'
+
             try:
                 self._keyboard_decoder = codecs.getincrementaldecoder(self._encoding)()
             except LookupError as err:
@@ -1106,20 +1109,33 @@ class Terminal(object):
         """
         return Sequence(text, self).strip_seqs()
 
-    def split_seqs(self, text, **kwds):
+    def split_seqs(self, text, maxsplit=0):
         r"""
         Return ``text`` split by individual character elements and sequences.
 
         :arg str text: String containing sequences
-        :arg kwds: remaining keyword arguments for :func:`re.split`.
+        :arg int maxsplit: When maxsplit is nonzero, at most maxsplit splits
+            occur, and the remainder of the string is returned as the final element
+            of the list (same meaning is argument for :func:`re.split`).
         :rtype: list[str]
         :returns: List of sequences and individual characters
 
         >>> term.split_seqs(term.underline(u'xyz'))
         ['\x1b[4m', 'x', 'y', 'z', '\x1b(B', '\x1b[m']
+
+        >>> term.split_seqs(term.underline(u'xyz'), 1)
+        ['\x1b[4m', r'xyz\x1b(B\x1b[m']
         """
         pattern = self._caps_unnamed_any
-        return list(filter(None, re.split(pattern, text, **kwds)))
+        result = []
+        for idx, match in enumerate(re.finditer(pattern, text)):
+            result.append(match.group())
+            if maxsplit and idx == maxsplit:
+                remaining = text[match.end():]
+                if remaining:
+                    result[-1] += remaining
+                break
+        return result
 
     def wrap(self, text, width=None, **kwargs):
         """
@@ -1139,11 +1155,11 @@ class Terminal(object):
         customize wrapping behaviour.
         """
         width = self.width if width is None else width
+        wrapper = SequenceTextWrapper(width=width, term=self, **kwargs)
         lines = []
         for line in text.splitlines():
             lines.extend(
-                (_linewrap for _linewrap in SequenceTextWrapper(
-                    width=width, term=self, **kwargs).wrap(line))
+                (_linewrap for _linewrap in wrapper.wrap(line))
                 if line.strip() else (u'',))
 
         return lines
